<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>dock::MultiTaskView</name>
    <message>
        <source>Multitasking View</source>
        <translation>多任务视图</translation>
    </message>
</context>
<context>
    <name>multitaskview</name>
    <message>
        <source>Multitasking View</source>
        <translation>多任务视图</translation>
    </message>
</context>
</TS>